<?php

namespace Litecms\Deposit\Policies;

use Litepie\User\Contracts\UserPolicy;
use Litecms\Deposit\Models\Deposit;

class DepositPolicy
{

    /**
     * Determine if the given user can view the deposit.
     *
     * @param UserPolicy $user
     * @param Deposit $deposit
     *
     * @return bool
     */
    public function view(UserPolicy $user, Deposit $deposit)
    {
        if ($user->canDo('deposit.deposit.view') && $user->isAdmin()) {
            return true;
        }

        return $deposit->user_id == user_id() && $deposit->user_type == user_type();
    }

    /**
     * Determine if the given user can create a deposit.
     *
     * @param UserPolicy $user
     * @param Deposit $deposit
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('deposit.deposit.create');
    }

    /**
     * Determine if the given user can update the given deposit.
     *
     * @param UserPolicy $user
     * @param Deposit $deposit
     *
     * @return bool
     */
    public function update(UserPolicy $user, Deposit $deposit)
    {
        if ($user->canDo('deposit.deposit.edit') && $user->isAdmin()) {
            return true;
        }

        return $deposit->user_id == user_id() && $deposit->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given deposit.
     *
     * @param UserPolicy $user
     * @param Deposit $deposit
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Deposit $deposit)
    {
        return $deposit->user_id == user_id() && $deposit->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given deposit.
     *
     * @param UserPolicy $user
     * @param Deposit $deposit
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Deposit $deposit)
    {
        if ($user->canDo('deposit.deposit.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given deposit.
     *
     * @param UserPolicy $user
     * @param Deposit $deposit
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Deposit $deposit)
    {
        if ($user->canDo('deposit.deposit.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
